.. apsimNGpy documentation master file, created by
   sphinx-quickstart on Sun Mar 30 22:19:37 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

apsimNGpy Documentation
=======================

apsimNGpy: The Next-Generation Agro-ecosystem Simulation Library
================================================================

apsimNGpy is a cutting-edge, open-source framework designed for advanced agroecosystem modeling.
Built on object-oriented principles, it provides:

- Fast batch file simulation
- Model prediction and evaluation
- Seamless APSIMX file editing
- Weather data retrieval
- Efficient soil profile development

.. automodule:: apsimNGpy
    :members:

.. toctree::
   :maxdepth: 4
   :caption: Table of Contents

   Home <self>
   getting started
   Usage
   model inspection
   cli
   factorial_experiments
   api



